@@ -22,7 +22,7 @@ package MongoDB;
 # ABSTRACT: Official MongoDB Driver for Perl
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 # regexp_pattern was unavailable before 5.10, had to be exported to load the
 # function implementation on 5.10, and was automatically available in 5.10.1
@@ -91,8 +91,6 @@ sub force_int {
 
 1;
 
-__END__
-
 =pod
 
 =encoding UTF-8
@@ -103,7 +101,7 @@ MongoDB - Official MongoDB Driver for Perl
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 This is Release Candidate 1 (RC1) for v1.0.0.
 
@@ -256,6 +254,14 @@ Odd-value increments of C<Y> indicate unstable ("development") releases that sho
 See the Changes file included with releases for an indication of the nature of
 changes involved.
 
+=head1 ENVIRONMENT VARIABLES
+
+If the C<PERL_MONGO_WITH_ASSERTS> environment variable is true before the
+MongoDB module is loaded, then its various classes will be generated with
+internal type assertions enabled.  This has a severe performance cost and
+is not recommended for production use.  It may be useful in diagnosing
+bugs.
+
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
@@ -295,7 +301,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrew Page Andrey Khozov Ashley Willis Ask Bjørn Hansen Brendan W. McAdams Casey Rojas chansen Christian Sturm Walde Colin Cyr danny David Morrison Nadle Steinbrunner Storch D. Ilmari Mannsåker Eric Daniels Gerard Goossen Glenn Fowler Graham Barr Jason Carey Toffaletti Johann Rolschewski Joseph Harnish Joshua Juran J. Stewart Kamil Slowikowski Ken Williams mapbuh Matthew Shopsin Michael Langner Rotmanov Mike Dirolf nightlord nightsailer Nuno Carvalho Orlando Vazquez Othello Maurer Robin Lee Roman Yerin Ronald J Kimball Ryan Chipman Stephen Oberholtzer Steve Sanbeg Stuart Watt Uwe Voelker Whitney.Jackson Xtreak
+=for stopwords Andrew Page Andrey Khozov Ashley Willis Ask Bjørn Hansen Bernard Gorman Brendan W. McAdams Casey Rojas chansen Christian Sturm Walde Colin Cyr danny David Morrison Nadle Steinbrunner Storch D. Ilmari Mannsåker Eric Daniels Gerard Goossen Glenn Fowler Graham Barr Jason Carey Toffaletti Johann Rolschewski Joseph Harnish Joshua Juran J. Stewart Kamil Slowikowski Ken Williams mapbuh Matthew Shopsin Michael Langner Rotmanov Mike Dirolf nightlord nightsailer Nuno Carvalho Orlando Vazquez Othello Maurer Robin Lee Roman Yerin Ronald J Kimball Ryan Chipman Stephen Oberholtzer Steve Sanbeg Stuart Watt Uwe Voelker Whitney.Jackson Xtreak
 
 =over 4
 
@@ -317,6 +323,10 @@ Ask Bjørn Hansen <ask@develooper.com>
 
 =item *
 
+Bernard Gorman <bernard.gorman@mongodb.com>
+
+=item *
+
 Brendan W. McAdams <brendan@mongodb.com>
 
 =item *
@@ -502,3 +512,8 @@ This is free software, licensed under:
   The Apache License, Version 2.0, January 2004
 
 =cut
+
+__END__
+
+
+# vim: set ts=4 sts=4 sw=4 et tw=75:
