@@ -20,7 +20,7 @@ package MongoDB::BSON;
 # ABSTRACT: Tools for serializing and deserializing data in BSON form
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 
 use XSLoader;
@@ -29,10 +29,20 @@ XSLoader::load("MongoDB", $VERSION);
 use Carp ();
 use Config;
 use if ! $Config{use64bitint}, "Math::BigInt";
+use DateTime;
 use MongoDB::Error;
-use Moose;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use Moo;
+use MongoDB::_Types qw(
+    NonNegNum
+    SingleChar
+);
+use Types::Standard qw(
+    Bool
+    CodeRef
+    Maybe
+    Str
+    Undef
+);
 use boolean;
 use namespace::clean -except => 'meta';
 
@@ -70,8 +80,6 @@ has dbref_callback => (
 #pod and C<undef>. The latter will give you the raw epoch value rather than an
 #pod object.
 #pod
-#pod # XXX add MongoDB::BSON::DateTime support and make it the default
-#pod
 #pod =cut
 
 has dt_type => (
@@ -97,9 +105,6 @@ has dt_type => (
 #pod
 #pod =cut
 
-# XXX should this be separate for encode & decode? e.g. encode always want
-# to throw with document and decode doesn't?
-
 has error_callback => (
     is      => 'ro',
     isa     => Maybe[CodeRef],
@@ -118,61 +123,6 @@ has invalid_chars => (
     default => '',
 );
 
-## XXX don't need this yet; do with 'invalid_chars' first for now
-##
-##=attr key_validator
-##
-##This attribute must be either a regular expresssion reference or
-##a function reference to validate a key during encoding.
-##
-##A function reference will get a single string argument and must return
-##an error string if the key is B<invalid>; if the key is B<valid> it must
-##return B<nothing>.
-##
-##A regular expression will be matched against the key; if it matches, the
-##key is valid.
-##
-##If not provided, any key is ok.
-##
-##=cut
-##
-##has key_validator => (
-##    is      => 'ro',
-##    isa     => Maybe[RegexpRef|CodeRef],
-##);
-##
-## XXX don't need this until encode_many is implemented
-##
-##=attr max_batch_size
-##
-##This attribute defines the maximum number of documents to return in a chunk
-##when using C<encode_many>.  The default is 0, which disables any maximum.
-##
-##=cut
-##
-##has max_batch_size=> (
-##    is => 'ro',
-##    isa => NonNegNum,
-##    default => 0,
-##);
-
-## XXX don't need this until we have a back-end that isn't hard-coded
-##
-##=attr max_depth
-##
-##This attribute defines the maximum document depth allowed.  The default
-##is 100 for both encoding and decoding.
-##
-##This
-##
-##=cut
-##
-##has max_depth => (
-##    is => 'ro',
-##    isa => NonNegNum,
-##    default => 100,
-##);
-
 #pod =attr max_length
 #pod
 #pod This attribute defines the maximum document size. The default is 0, which
@@ -330,7 +280,6 @@ sub clone {
     return $class->new( %$self, @args );
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -346,7 +295,7 @@ MongoDB::BSON - Tools for serializing and deserializing data in BSON form
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
@@ -384,8 +333,6 @@ is L<DateTime>. Other acceptable values are L<Time::Moment>, L<DateTime::Tiny>
 and C<undef>. The latter will give you the raw epoch value rather than an
 object.
 
-# XXX add MongoDB::BSON::DateTime support and make it the default
-
 =head2 error_callback
 
 This attribute specifies a function reference that will be called with
