@@ -18,10 +18,13 @@ package MongoDB::BSON::Binary;
 # ABSTRACT: MongoDB binary type
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
-use Types::Standard -types;
+use Types::Standard qw(
+    Int
+    Str
+);
 use namespace::clean;
 
 use constant {
@@ -78,7 +81,7 @@ MongoDB::BSON::Binary - MongoDB binary type
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
