@@ -2,11 +2,13 @@ package MongoDB::BSON::Regexp;
 # ABSTRACT: Regular expression type
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
+use Moo;
 use MongoDB::Error;
-use Types::Standard -types;
+use Types::Standard qw(
+    Str
+);
 use namespace::clean -except => 'meta';
 
 has pattern => (
@@ -70,7 +72,6 @@ sub try_compile {
     return $re;
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -88,7 +89,7 @@ MongoDB::BSON::Regexp - Regular expression type
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 METHODS
 
