@@ -19,12 +19,14 @@ package MongoDB::BSON::_EncodedDoc;
 # Wrapper for pre-encoded BSON documents, with optional metadata
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use Types::Standard qw(
+    HashRef
+    Str
+);
 use namespace::clean;
 
 # An encoded document, i.e. a BSON string
