@@ -19,18 +19,23 @@ package MongoDB::BulkWrite;
 # ABSTRACT: MongoDB bulk write interface
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use MongoDB::Error;
 use MongoDB::OID;
 use MongoDB::Op::_BulkWrite;
 use MongoDB::BulkWriteResult;
 use MongoDB::BulkWriteView;
-use Syntax::Keyword::Junction qw/any/;
 
-use Moose;
-use MongoDB::_Types -types, 'to_WriteConcern';
-use Types::Standard -types;
+use Moo;
+use MongoDB::_Types qw(
+    to_WriteConcern
+);
+use Types::Standard qw(
+    ArrayRef
+    Bool
+    InstanceOf
+);
 use namespace::clean -except => 'meta';
 
 #pod =attr collection (required)
@@ -70,19 +75,22 @@ has '_queue' => (
     isa      => ArrayRef[ArrayRef],
     init_arg => undef,
     default  => sub { [] },
-    traits   => ['Array'],
-    handles  => {
-        _enqueue_write => 'push',
-        _all_writes    => 'elements',
-        _count_writes  => 'count',
-        _clear_writes  => 'clear',
-    }
 );
 
+sub _enqueue_write {
+    my $self = shift;
+    push @{$self->{_queue}}, @_;
+}
+
+sub _all_writes { return @{$_[0]->{_queue}} }
+
+sub _count_writes { return scalar @{$_[0]->{_queue}} }
+
+sub _clear_writes { @{$_[0]->{_queue}} = (); return; }
+
 has '_database' => (
-    is         => 'ro',
+    is         => 'lazy',
     isa        => InstanceOf['MongoDB::Database'],
-    lazy_build => 1,
 );
 
 sub _build__database {
@@ -91,9 +99,8 @@ sub _build__database {
 }
 
 has '_client' => (
-    is         => 'ro',
+    is         => 'lazy',
     isa        => InstanceOf['MongoDB::MongoClient'],
-    lazy_build => 1,
 );
 
 sub _build__client {
@@ -122,7 +129,8 @@ sub find {
     MongoDB::UsageError->throw("find requires a criteria document. Use an empty hashref for no criteria.")
       unless defined $doc;
 
-    unless ( @_ == 2 && ref $doc eq any(qw/HASH ARRAY Tie::IxHash/) ) {
+    my $type = ref $doc;
+    unless ( @_ == 2 && grep { $type eq $_ } qw/HASH ARRAY Tie::IxHash/ ) {
         MongoDB::UsageError->throw("argument to find must be a single hashref, arrayref or Tie::IxHash");
     }
 
@@ -245,7 +253,6 @@ BEGIN {
     *insert = \&insert_one;
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -261,7 +268,7 @@ MongoDB::BulkWrite - MongoDB bulk write interface
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
