@@ -19,7 +19,7 @@ package MongoDB::BulkWriteResult;
 # ABSTRACT: MongoDB bulk write result document
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 # empty superclass for backcompatibility; add a variable to the
 # package namespace so Perl thinks it's a real package
@@ -28,9 +28,14 @@ $MongoDB::WriteResult::VERSION = $VERSION;
 use Moo;
 use MongoDB::Error;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
-use Syntax::Keyword::Junction qw/any/;
+use MongoDB::_Types qw(
+    ArrayOfHashRef
+);
+use Types::Standard qw(
+    HashRef
+    Num
+    Undef
+);
 use namespace::clean;
 
 # fake empty superclass for backcompat
@@ -43,17 +48,16 @@ with $_ for qw(
 );
 
 has [qw/upserted inserted/] => (
-    is         => 'ro',
-      required => 1,
-      isa      => ArrayOfHashRef,
+    is       => 'ro',
+    required => 1,
+    isa      => ArrayOfHashRef,
 );
 
 has inserted_ids => (
-    is         => 'ro',
-      lazy     => 1,
-      builder  => '_build_inserted_ids',
-      init_arg => undef,
-      isa      => HashRef,
+    is       => 'lazy',
+    builder  => '_build_inserted_ids',
+    init_arg => undef,
+    isa      => HashRef,
 );
 
 sub _build_inserted_ids {
@@ -62,11 +66,10 @@ sub _build_inserted_ids {
 }
 
 has upserted_ids => (
-    is         => 'ro',
-      lazy     => 1,
-      builder  => '_build_upserted_ids',
-      init_arg => undef,
-      isa      => HashRef,
+    is       => 'lazy',
+    builder  => '_build_upserted_ids',
+    init_arg => undef,
+    isa      => HashRef,
 );
 
 sub _build_upserted_ids {
@@ -165,7 +168,7 @@ sub _parse_cmd_result {
       if eval { $result->isa("MongoDB::CommandResult") };
 
     MongoDB::UsageError->throw("op argument to parse must be one of: @op_map_keys")
-      unless $op eq any(@op_map_keys);
+      unless grep { $op eq $_ } @op_map_keys;
     MongoDB::UsageError->throw("results argument to parse must be a hash reference")
       unless ref $result eq 'HASH';
 
@@ -331,7 +334,7 @@ MongoDB::BulkWriteResult - MongoDB bulk write result document
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
