@@ -19,14 +19,18 @@ package MongoDB::BulkWriteView;
 # ABSTRACT: Bulk write operations against a query document
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
+use Moo;
 
-use Syntax::Keyword::Junction qw/any/;
 use MongoDB::Error;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    IxHash
+    Booleanpm
+);
+use Types::Standard qw(
+    InstanceOf
+);
 use boolean;
 use namespace::clean -except => 'meta';
 
@@ -79,7 +83,8 @@ sub _update {
     my $method = pop @_;
     my ( $self, $doc ) = @_;
 
-    unless ( @_ == 2 && ref $doc eq any(qw/HASH ARRAY Tie::IxHash/) ) {
+    my $type = ref $doc;
+    unless ( @_ == 2 && grep { $type eq $_ } qw/HASH ARRAY Tie::IxHash/ ) {
         MongoDB::UsageError->throw("argument to $method must be a single hashref, arrayref or Tie::IxHash");
     }
 
@@ -128,7 +133,6 @@ BEGIN {
     *remove_one = \&delete_one;
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -144,7 +148,7 @@ MongoDB::BulkWriteView - Bulk write operations against a query document
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
