@@ -20,7 +20,7 @@ package MongoDB::Code;
 # ABSTRACT: JavaScript Code
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 #pod =head1 NAME
 #pod
@@ -28,8 +28,11 @@ our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
 #pod
 #pod =cut
 
-use Moose;
-use Types::Standard -types;
+use Moo;
+use Types::Standard qw(
+    HashRef
+    Str
+);
 use namespace::clean -except => 'meta';
 
 #pod =head1 ATTRIBUTES
@@ -58,7 +61,6 @@ has scope => (
     required => 0,
 );
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -74,7 +76,7 @@ MongoDB::Code - JavaScript Code
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 NAME
 
