@@ -20,7 +20,7 @@ package MongoDB::Collection;
 # ABSTRACT: A MongoDB Collection
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use MongoDB::Error;
 use MongoDB::IndexView;
@@ -37,16 +37,24 @@ use MongoDB::Op::_Distinct;
 use MongoDB::Op::_InsertOne;
 use MongoDB::Op::_ListIndexes;
 use MongoDB::Op::_Update;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    BSONCodec
+    NonNegNum
+    ReadPreference
+    WriteConcern
+);
+use Types::Standard qw(
+    HashRef
+    InstanceOf
+    Str
+);
 use Tie::IxHash;
 use Carp 'carp';
 use boolean;
 use Safe::Isa;
 use Scalar::Util qw/blessed reftype/;
-use Syntax::Keyword::Junction qw/any/;
 use Try::Tiny;
-use Moose;
+use Moo;
 use namespace::clean -except => 'meta';
 
 #--------------------------------------------------------------------------#
@@ -155,9 +163,8 @@ has bson_codec => (
 #pod =cut
 
 has _client => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => InstanceOf['MongoDB::MongoClient'],
-    lazy    => 1,
     reader  => 'client',
     init_arg => undef,
     builder => '_build__client',
@@ -179,9 +186,8 @@ sub _build__client {
 #pod =cut
 
 has _full_name => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     reader  => 'full_name',
     init_arg => undef,
     builder => '_build__full_name',
@@ -207,9 +213,8 @@ sub _build__full_name {
 #pod =cut
 
 has _indexes => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => InstanceOf['MongoDB::IndexView'],
-    lazy    => 1,
     reader  => 'indexes',
     init_arg => undef,
     builder => '_build__indexes',
@@ -222,9 +227,8 @@ sub _build__indexes {
 
 # these are constant, so we cache them
 has _op_args => (
-    is       => 'ro',
+    is       => 'lazy',
     isa      => HashRef,
-    lazy     => 1,
     init_arg => undef,
     builder  => '_build__op_args',
 );
@@ -1057,16 +1061,16 @@ sub parallel_scan {
         my $batch = $c->{firstBatch};
         my $qr = MongoDB::QueryResult->_new(
             _client    => $self->client,
-            address    => $result->address,
-            ns         => $c->{ns},
-            bson_codec => $self->bson_codec,
-            batch_size   => scalar @$batch,
-            cursor_at    => 0,
-            limit        => 0,
-            cursor_id    => MongoDB::QueryResult::_pack_cursor_id($c->{id}),
-            cursor_start => 0,
-            cursor_flags => {},
-            cursor_num   => scalar @$batch,
+            _address    => $result->address,
+            _ns         => $c->{ns},
+            _bson_codec => $self->bson_codec,
+            _batch_size   => scalar @$batch,
+            _cursor_at    => 0,
+            _limit        => 0,
+            _cursor_id    => MongoDB::QueryResult::_pack_cursor_id($c->{id}),
+            _cursor_start => 0,
+            _cursor_flags => {},
+            _cursor_num   => scalar @$batch,
             _docs        => $batch,
         );
         push @cursors, $qr;
@@ -1372,7 +1376,6 @@ sub _run_command {
 sub _try_find_and_modify {
     my ($self, $command) = @_;
     my $result;
-    # XXX this ought to use our codec
     try {
         $result = $self->_run_command( $command );
     }
@@ -1699,7 +1702,6 @@ sub validate {
     my $obj = $self->_run_command({ validate => $self->name });
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -1713,7 +1715,7 @@ MongoDB::Collection - A MongoDB Collection
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
