@@ -19,13 +19,17 @@ package MongoDB::CommandResult;
 # ABSTRACT: MongoDB generic command result document
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 use MongoDB::Error;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    HostAddress
+);
+use Types::Standard qw(
+    HashRef
+);
 use namespace::clean;
 
 with $_ for qw(
@@ -134,7 +138,7 @@ MongoDB::CommandResult - MongoDB generic command result document
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 DESCRIPTION
 
