@@ -20,9 +20,9 @@ package MongoDB::Cursor;
 # ABSTRACT: A lazy cursor for Mongo query results
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
+use Moo;
 use MongoDB;
 use MongoDB::BSON;
 use MongoDB::Error;
@@ -30,7 +30,9 @@ use MongoDB::QueryResult;
 use MongoDB::ReadPreference;
 use MongoDB::_Protocol;
 use MongoDB::_Types -types, 'to_IxHash';
-use Types::Standard -types;
+use Types::Standard qw(
+    InstanceOf
+);
 use boolean;
 use Tie::IxHash;
 use Try::Tiny;
@@ -38,9 +40,9 @@ use namespace::clean -except => 'meta';
 
 #pod =attr started_iterating
 #pod
-#pod If this cursor has queried the database yet. Methods
-#pod modifying the query will complain if they are called
-#pod after the database is queried.
+#pod A boolean indicating if this cursor has queried the database yet. Methods
+#pod modifying the query will complain if they are called after the database is
+#pod queried.
 #pod
 #pod =cut
 
@@ -55,9 +57,8 @@ has query => (
 
 # lazy result attribute
 has result => (
-    is        => 'ro',
+    is        => 'lazy',
     isa       => InstanceOf['MongoDB::QueryResult'],
-    lazy      => 1,
     builder   => '_build_result',
     predicate => 'started_iterating',
     clearer   => '_clear_result',
@@ -84,19 +85,15 @@ sub _build_result {
 #pod
 #pod Ordinarily, a cursor "dies" on the database server after a certain length of
 #pod time (approximately 10 minutes), to prevent inactive cursors from hogging
-#pod resources.  This option sets that a cursor should not die until all of its
+#pod resources.  This option indicates that a cursor should not die until all of its
 #pod results have been fetched or it goes out of scope in Perl.
 #pod
 #pod Boolean value, defaults to 0.
 #pod
-#pod C<immortal> is not equivalent to setting a client-side timeout.  If you are
-#pod getting client-side timeouts (e.g., "recv timed out"), set C<query_timeout> on
-#pod your connection.
-#pod
-#pod     # wait forever for a query to return results
-#pod     $connection->query_timeout(-1);
-#pod
-#pod See L<MongoDB::MongoClient/query_timeout>.
+#pod Note: C<immortal> only affects the server-side timeout.  If you are getting
+#pod client-side timeouts you will need to change your client configuration.
+#pod See L<MongoDB::MongoClient/max_time_ms> and
+#pod L<MongoDB::MongoClient/socket_timeout_ms>.
 #pod
 #pod Returns this cursor for chaining operations.
 #pod
@@ -121,8 +118,8 @@ sub immortal {
 #pod
 #pod Selects which fields are returned.  The default is all fields.  When fields
 #pod are specified, _id is returned by default, but this can be disabled by
-#pod explicitly setting it to "0".  E.g.  C<< _id => 0 >>. Argument is either a
-#pod hash reference, a L<Tie::IxHash> or an array reference of key/value pairs.
+#pod explicitly setting it to "0".  E.g.  C<< _id => 0 >>. Argument must be either a
+#pod hash reference or a L<Tie::IxHash> object.
 #pod
 #pod See L<Limit fields to
 #pod return|http://docs.mongodb.org/manual/tutorial/project-fields-from-query-results/>
@@ -360,7 +357,7 @@ sub partial {
 
     $self->query->allowPartialResults( !! $value );
 
-    # XXX returning self is an API change but more consistent with other cursor methods
+    # returning self is an API change but more consistent with other cursor methods
     return $self;
 }
 
@@ -531,7 +528,7 @@ sub reset {
 sub info {
     my $self = shift;
     if ( $self->started_iterating ) {
-        return $self->result->info;
+        return $self->result->_info;
     }
     else {
         return { num => 0 };
@@ -544,7 +541,6 @@ sub info {
 
 sub count {
     my ($self, $limit_skip) = @_;
-    # XXX deprecate this unintuitive API?
 
     my $cmd = new Tie::IxHash(count => $self->query->coll_name);
 
@@ -591,11 +587,10 @@ sub slave_okay {
         $self->query->read_preference( $PRIMARY );
     }
 
-    # XXX returning self is an API change but more consistent with other cursor methods
+    # returning self is an API change but more consistent with other cursor methods
     return $self;
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -615,7 +610,7 @@ MongoDB::Cursor - A lazy cursor for Mongo query results
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
@@ -637,9 +632,9 @@ thread.
 
 =head2 started_iterating
 
-If this cursor has queried the database yet. Methods
-modifying the query will complain if they are called
-after the database is queried.
+A boolean indicating if this cursor has queried the database yet. Methods
+modifying the query will complain if they are called after the database is
+queried.
 
 =head1 QUERY MODIFIERS
 
@@ -652,19 +647,15 @@ they are called after results are iterated.
 
 Ordinarily, a cursor "dies" on the database server after a certain length of
 time (approximately 10 minutes), to prevent inactive cursors from hogging
-resources.  This option sets that a cursor should not die until all of its
+resources.  This option indicates that a cursor should not die until all of its
 results have been fetched or it goes out of scope in Perl.
 
 Boolean value, defaults to 0.
 
-C<immortal> is not equivalent to setting a client-side timeout.  If you are
-getting client-side timeouts (e.g., "recv timed out"), set C<query_timeout> on
-your connection.
-
-    # wait forever for a query to return results
-    $connection->query_timeout(-1);
-
-See L<MongoDB::MongoClient/query_timeout>.
+Note: C<immortal> only affects the server-side timeout.  If you are getting
+client-side timeouts you will need to change your client configuration.
+See L<MongoDB::MongoClient/max_time_ms> and
+L<MongoDB::MongoClient/socket_timeout_ms>.
 
 Returns this cursor for chaining operations.
 
@@ -678,8 +669,8 @@ Returns this cursor for chaining operations.
 
 Selects which fields are returned.  The default is all fields.  When fields
 are specified, _id is returned by default, but this can be disabled by
-explicitly setting it to "0".  E.g.  C<< _id => 0 >>. Argument is either a
-hash reference, a L<Tie::IxHash> or an array reference of key/value pairs.
+explicitly setting it to "0".  E.g.  C<< _id => 0 >>. Argument must be either a
+hash reference or a L<Tie::IxHash> object.
 
 See L<Limit fields to
 return|http://docs.mongodb.org/manual/tutorial/project-fields-from-query-results/>
