@@ -20,7 +20,7 @@ package MongoDB::Database;
 # ABSTRACT: A MongoDB Database
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use MongoDB::CommandResult;
 use MongoDB::Error;
@@ -28,11 +28,19 @@ use MongoDB::GridFS;
 use MongoDB::Op::_ListCollections;
 use MongoDB::ReadPreference;
 use MongoDB::_Query;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    BSONCodec
+    NonNegNum
+    ReadPreference
+    WriteConcern
+);
+use Types::Standard qw(
+    InstanceOf
+    Str
+);
 use Carp 'carp';
 use boolean;
-use Moose;
+use Moo;
 use Try::Tiny;
 use namespace::clean -except => 'meta';
 
@@ -384,7 +392,6 @@ sub last_error {
     return $self->run_command( [ getlasterror => 1, ( $opt ? %$opt : () ) ] );
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -400,7 +407,7 @@ MongoDB::Database - A MongoDB Database
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
