@@ -19,12 +19,13 @@ package MongoDB::DeleteResult;
 # ABSTRACT: MongoDB deletion result object
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use Types::Standard qw(
+    Num
+);
 use namespace::clean;
 
 with $_ for qw(
@@ -58,7 +59,7 @@ MongoDB::DeleteResult - MongoDB deletion result object
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
