@@ -13,24 +13,29 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 #
-
 use 5.008;
 use strict;
 use warnings;
 
 package MongoDB::Error;
+
 # ABSTRACT: MongoDB Driver Error classes
 
-use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+# Portions adapted from Throwable.pm by Ricardo Signes
 
-use Moose;
+use version;
+
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
+
+use Moo;
 use Carp;
-use Moose::Meta::Class ();
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    ErrorStr
+);
+use Scalar::Util ();
+use Sub::Quote ();
 use Exporter 5.57 qw/import/;
-use namespace::clean -except => [ 'meta', 'import' ];
+use namespace::clean -except => ['import'];
 
 my $ERROR_CODES;
 
@@ -55,10 +60,12 @@ BEGIN {
 
 use constant $ERROR_CODES;
 
-# Export error codes for use by end-users; this is unusual for Moose, but
+# Export error codes for use by end-users; this is unusual for Moo, but
 # probably sufficiently helpful to justify it
 our @EXPORT = keys %$ERROR_CODES;
 
+our %_HORRIBLE_HACK;
+
 use overload (
     q{""} => sub {
         my $self = shift;
@@ -73,39 +80,44 @@ has message => (
     default => 'unspecified error',
 );
 
-#pod =method throw
-#pod
-#pod     MongoDB::Error->throw( "message" );
-#pod     MongoDB::Error->throw( message => "message" );
-#pod     MongoDB::Error->throw( $error_object );
-#pod
-#pod =cut
-
-with 'Throwable';
-
-around BUILDARGS => sub {
-    my $orig  = shift;
-    my $class = shift;
-    if ( @_ == 1 && !ref $_[0] ) {
-        return $class->$orig( message => $_[0] );
+has 'previous_exception' => (
+  is       => 'ro',
+  default  => Sub::Quote::quote_sub(q<
+    if (defined $MongoDB::Error::_HORRIBLE_HACK{ERROR}) {
+      $MongoDB::Error::_HORRIBLE_HACK{ERROR}
+    } elsif (defined $@ and (ref $@ or length $@)) {
+      $@;
+    } else {
+      undef;
     }
-    return $class->$orig(@_);
-};
+  >),
+);
 
-__PACKAGE__->meta->make_immutable;
+sub throw {
+  my ($inv) = shift;
+
+  if (Scalar::Util::blessed($inv)) {
+    Carp::confess "throw called on MongoDB::Error object with arguments" if @_;
+    die $inv;
+  }
+
+  local $_HORRIBLE_HACK{ERROR} = $@;
+
+  my $throwable = @_ == 1 ? $inv->new( message => $_[0] ) : $inv->new(@_);
+
+  die $throwable;
+}
 
 #--------------------------------------------------------------------------#
 # Subclasses with attributes included inline below
 #--------------------------------------------------------------------------#
 
 package MongoDB::DatabaseError;
-use Moose;
-use Types::Standard -types;
-use namespace::clean -except => 'meta';
-extends("MongoDB::Error");
+use Moo;
+use Types::Standard qw(Num);
+use namespace::clean;
 
-# XXX should rename to 'details' or 'error' or something less confusing than
-# the word 'result'
+extends("MongoDB::Error");
 
 has result => (
     is       => 'ro',
@@ -121,13 +133,12 @@ has code => (
 
 sub _build_code { return MongoDB::Error::UNKNOWN_ERROR() }
 
-__PACKAGE__->meta->make_immutable;
-
 package MongoDB::DocumentError;
-use Moose;
-use MongoDB::_Types -types;
-use Types::Standard -types;
-use namespace::clean -except => 'meta';
+
+use Moo;
+use Types::Standard qw(Any);
+use namespace::clean;
+
 extends("MongoDB::Error");
 
 has document => (
@@ -136,168 +147,143 @@ has document => (
     required => 1,
 );
 
-__PACKAGE__->meta->make_immutable;
-
 package MongoDB::UsageError;
-use Moose;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+
+use Moo;
+use Types::Standard qw(Str);
 use namespace::clean -except => 'meta';
+
 extends("MongoDB::Error");
 
 use overload (
     q{""} => sub {
         my $self = shift;
-        return
-          sprintf( "%s: %s%s", ref($self), $self->message, $self->trace );
+        return sprintf( "%s: %s%s", ref($self), $self->message, $self->trace );
     },
     fallback => 1
 );
 
 has trace => (
-    is       => 'ro',
-    isa      => Str,
+    is  => 'ro',
+    isa => Str,
 );
 
 around BUILDARGS => sub {
     my $orig  = shift;
     my $class = shift;
-    my $args = $class->SUPER::BUILDARGS(@_);
-
+    my $args  = $class->SUPER::BUILDARGS(@_);
     # start stack trace above where throw() is called (or
     # at the top of the stack), so it works like confess
     my $i = 0;
     while ( my @caller = caller($i) ) {
         $i++;
-        last if $caller[0] eq "Throwable";
+        last if $caller[0] eq "MongoDB::Error";
     }
-    local $Carp::CarpLevel = caller($i + 1)? $i + 1 : $i;
+    local $Carp::CarpLevel = caller( $i + 1 ) ? $i + 1 : $i;
     $args->{trace} = Carp::longmess('');
     return $args;
 };
 
-__PACKAGE__->meta->make_immutable;
-
-#--------------------------------------------------------------------------#
-# Empty subclasses generated programatically; this keeps packages visible
-# to metadata inspectors, but is shorter than Moose/namespace::clean/extends
-#--------------------------------------------------------------------------#
-
 # Connection errors
-
 package MongoDB::ConnectionError;
-Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::Error';
 
 package MongoDB::HandshakeError;
-Moose::Meta::Class->create( __PACKAGE__,
-    superclasses => ['MongoDB::ConnectionError'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::ConnectionError';
 
 package MongoDB::NetworkError;
-Moose::Meta::Class->create( __PACKAGE__,
-    superclasses => ['MongoDB::ConnectionError'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::ConnectionError';
 
 # Timeout errors
-
 package MongoDB::TimeoutError;
-Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::Error';
 
 package MongoDB::ExecutionTimeout;
-Moose::Meta::Class->create( __PACKAGE__,
-    superclasses => ['MongoDB::TimeoutError'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::TimeoutError';
 
 package MongoDB::NetworkTimeout;
-Moose::Meta::Class->create( __PACKAGE__,
-    superclasses => ['MongoDB::TimeoutError'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::TimeoutError';
 
 # Database errors
-
 package MongoDB::DuplicateKeyError;
-Moose::Meta::Class->create( __PACKAGE__,
-    superclasses => ['MongoDB::DatabaseError'] );
-
+use Moo;
+use namespace::clean;
+extends 'MongoDB::DatabaseError';
 sub _build_code { return MongoDB::Error::DUPLICATE_KEY() }
 
-__PACKAGE__->meta->make_immutable;
-
 package MongoDB::NotMasterError;
-Moose::Meta::Class->create( __PACKAGE__,
-    superclasses => ['MongoDB::DatabaseError'] );
-
+use Moo;
+use namespace::clean;
+extends 'MongoDB::DatabaseError';
 sub _build_code { return MongoDB::Error::NOT_MASTER() }
 
-__PACKAGE__->meta->make_immutable;
-
 package MongoDB::WriteError;
-Moose::Meta::Class->create( __PACKAGE__,
-    superclasses => ['MongoDB::DatabaseError'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::DatabaseError';
 
 package MongoDB::WriteConcernError;
-Moose::Meta::Class->create( __PACKAGE__,
-    superclasses => ['MongoDB::DatabaseError'] );
-
+use Moo;
+use namespace::clean;
+extends 'MongoDB::DatabaseError';
 sub _build_code { return MongoDB::Error::WRITE_CONCERN_ERROR() }
 
-__PACKAGE__->meta->make_immutable;
-
 # Other errors
-
 package MongoDB::AuthError;
-Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::Error';
 
 package MongoDB::CursorNotFoundError;
-Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::Error';
 
 package MongoDB::DecodingError;
-Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::Error';
 
 package MongoDB::GridFSError;
-Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::Error';
 
 package MongoDB::InternalError;
-Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::Error';
 
 package MongoDB::ProtocolError;
-Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::Error';
 
 package MongoDB::SelectionError;
-Moose::Meta::Class->create( __PACKAGE__, superclasses => ['MongoDB::Error'] );
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use namespace::clean;
+extends 'MongoDB::Error';
 
 #--------------------------------------------------------------------------#
 # Private error classes
 #--------------------------------------------------------------------------#
-
 package MongoDB::_CommandSizeError;
-use Moose;
-use Types::Standard -types;
-use namespace::clean -except => 'meta';
+use Moo;
+use Types::Standard qw(Int);
+use namespace::clean;
+
 extends("MongoDB::Error");
 
 has size => (
@@ -306,8 +292,6 @@ has size => (
     required => 1,
 );
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 =pod
@@ -320,14 +304,12 @@ MongoDB::Error - MongoDB Driver Error classes
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
     use MongoDB::Error;
-
     MongoDB::Error->throw("a generic error");
-
     MongoDB::DatabaseError->throw(
         message => $string,
         result => $hashref,
@@ -362,14 +344,6 @@ are recommended:
 
 To retry failures automatically, consider using L<Try::Tiny::Retry>.
 
-=head1 METHODS
-
-=head2 throw
-
-    MongoDB::Error->throw( "message" );
-    MongoDB::Error->throw( message => "message" );
-    MongoDB::Error->throw( $error_object );
-
 =head1 EXCEPTION HIERARCHY
 
     MongoDB::Error
@@ -549,8 +523,8 @@ C<connect_timeout_ms> or C<socket_timeout_ms>.
 
 Indicates invalid arguments or configuration options.  Not all usage errors
 will throw this — only ones originating directly from the MongoDB::* library
-files.  Some type and usage errors will originate from the L<Moose> object
-system if the objects are used incorrectly.
+files.  Some type and usage errors will originate from the L<Type::Tiny>
+library if the objects are used incorrectly.
 
 =head1 ERROR CODES
 
