@@ -20,16 +20,23 @@ package MongoDB::GridFS;
 # ABSTRACT: A file storage utility
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use MongoDB::GridFS::File;
-use DateTime 0.78; # drops dependency on bug-prone Math::Round
 use Digest::MD5;
-use Moose;
+use Moo;
 use MongoDB::Error;
 use MongoDB::WriteConcern;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    BSONCodec
+    NonNegNum
+    ReadPreference
+    WriteConcern
+);
+use Types::Standard qw(
+    InstanceOf
+    Str
+);
 use namespace::clean -except => 'meta';
 
 #pod =attr chunk_size
@@ -122,9 +129,8 @@ has prefix => (
 );
 
 has files => (
-    is => 'ro',
+    is => 'lazy',
     isa => InstanceOf['MongoDB::Collection'],
-    lazy_build => 1
 );
 
 sub _build_files {
@@ -142,9 +148,8 @@ sub _build_files {
 }
 
 has chunks => (
-    is => 'ro',
+    is => 'lazy',
     isa => InstanceOf['MongoDB::Collection'],
-    lazy_build => 1
 );
 
 sub _build_chunks {
@@ -333,6 +338,7 @@ sub remove {
 sub insert {
     my ($self, $fh, $metadata, $options) = @_;
     $options ||= {};
+    require DateTime; # lazy load so we don't have overhead if not needed
 
     MongoDB::UsageError->throw("not a file handle") unless $fh;
     $metadata = {} unless $metadata && ref $metadata eq 'HASH';
@@ -455,7 +461,6 @@ sub _dynamic_write_concern {
     }
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -471,7 +476,7 @@ MongoDB::GridFS - A file storage utility
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
