@@ -20,12 +20,15 @@ package MongoDB::GridFS::File;
 # ABSTRACT: A Mongo GridFS file
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use MongoDB::Error;
 use IO::File;
-use Moose;
-use Types::Standard -types;
+use Moo;
+use Types::Standard qw(
+    HashRef
+    InstanceOf
+);
 use namespace::clean -except => 'meta';
 
 has _grid => (
@@ -145,7 +148,6 @@ sub slurp {
     return $bytes;
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -161,7 +163,7 @@ MongoDB::GridFS::File - A Mongo GridFS file
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
