@@ -19,13 +19,22 @@ package MongoDB::IndexView;
 # ABSTRACT: Index management for a collection
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
+use Moo;
 use MongoDB::Error;
 use MongoDB::WriteConcern;
-use MongoDB::_Types -types, qw/is_OrderedDoc is_IndexModelList/;
-use Types::Standard qw/-types is_Str/;
+use MongoDB::_Types qw(
+    BSONCodec
+    IxHash
+    is_IndexModelList
+    is_OrderedDoc
+);
+use Types::Standard qw(
+    InstanceOf
+    Str
+    is_Str
+);
 use boolean;
 use namespace::clean -except => 'meta';
 
@@ -50,9 +59,8 @@ has collection => (
 #--------------------------------------------------------------------------#
 
 has _bson_codec => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => BSONCodec,
-    lazy    => 1,
     builder => '_build__bson_codec',
 );
 
@@ -62,9 +70,8 @@ sub _build__bson_codec {
 }
 
 has _client => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => InstanceOf( ['MongoDB::MongoClient'] ),
-    lazy    => 1,
     builder => '_build__client',
 );
 
@@ -74,9 +81,8 @@ sub _build__client {
 }
 
 has _coll_name => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     builder => '_build__coll_name',
 );
 
@@ -86,9 +92,8 @@ sub _build__coll_name {
 }
 
 has _db_name => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     builder => '_build__db_name',
 );
 
@@ -352,7 +357,6 @@ sub __to_index_string {
 
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -371,7 +375,7 @@ MongoDB::IndexView - Index management for a collection
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
