@@ -19,12 +19,17 @@ package MongoDB::InsertManyResult;
 # ABSTRACT: MongoDB single insert result object
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    ArrayOfHashRef
+);
+use Types::Standard qw(
+    HashRef
+    Num
+);
 use namespace::clean;
 
 with $_ for qw(
@@ -65,8 +70,7 @@ has inserted => (
 #pod =cut
 
 has inserted_ids => (
-    is      => 'ro',
-    lazy    => 1,
+    is      => 'lazy',
     builder => '_build_inserted_ids',
     isa => HashRef,
 );
@@ -90,7 +94,7 @@ MongoDB::InsertManyResult - MongoDB single insert result object
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
