@@ -19,12 +19,9 @@ package MongoDB::InsertOneResult;
 # ABSTRACT: MongoDB single insert result object
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
-use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
 use namespace::clean;
 
 with $_ for qw(
@@ -57,7 +54,7 @@ MongoDB::InsertOneResult - MongoDB single insert result object
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
