@@ -19,9 +19,9 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
+use Moo;
 use MongoDB;
 use MongoDB::BSON;
 use MongoDB::BSON::Binary;
@@ -39,30 +39,31 @@ use MongoDB::_URI;
 use Digest::MD5;
 use Tie::IxHash;
 use Time::HiRes qw/usleep/;
-use Carp 'carp', 'croak';
+use Carp 'carp', 'croak', 'confess';
 use Safe::Isa;
 use Scalar::Util qw/reftype weaken/;
-use Syntax::Keyword::Junction 'any';
 use boolean;
 use Encode;
 use Try::Tiny;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    ArrayOfHashRef
+    AuthMechanism
+    BSONCodec
+    NonNegNum
+    ReadPrefMode
+    ReadPreference
+);
+use Types::Standard qw(
+    Bool
+    HashRef
+    InstanceOf
+    Int
+    Num
+    Str
+);
+
 use namespace::clean -except => 'meta';
 
-use constant {
-    PRIMARY             => 'primary',
-    SECONDARY           => 'secondary',
-    PRIMARY_PREFERRED   => 'primaryPreferred',
-    SECONDARY_PREFERRED => 'secondaryPreferred',
-    NEAREST             => 'nearest',
-};
-
-use constant {
-    MAX_WIRE_VERSION => 3,
-    MIN_WIRE_VERSION => 0,
-};
-
 #--------------------------------------------------------------------------#
 # deprecated global variables
 #--------------------------------------------------------------------------#
@@ -92,7 +93,7 @@ $MongoDB::BSON::char = '$';
 has host => (
     is      => 'ro',
     isa     => Str,
-    default => 'mongodb://localhost:27017', # XXX eventually, make this localhost
+    default => 'mongodb://localhost:27017',
 );
 
 #pod =attr auth_mechanism
@@ -118,9 +119,8 @@ has host => (
 #pod =cut
 
 has auth_mechanism => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => AuthMechanism,
-    lazy    => 1,
     builder => '_build_auth_mechanism',
 );
 
@@ -152,9 +152,8 @@ sub _build_auth_mechanism {
 #pod =cut
 
 has auth_mechanism_properties => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => HashRef,
-    lazy    => 1,
     builder => '_build_auth_mechanism_properties',
 );
 
@@ -178,11 +177,10 @@ sub _build_auth_mechanism_properties {
 #pod =cut
 
 has bson_codec => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => BSONCodec,
     coerce  => 1,
     writer  => '_set_bson_codec',
-    lazy    => 1,
     builder => '_build_bson_codec',
 );
 
@@ -202,7 +200,7 @@ sub _build_bson_codec {
 #pod This attribute specifies the amount of time in milliseconds to wait for a
 #pod new connection to a server.
 #pod
-#pod The default is 20,000 ms.
+#pod The default is 10,000 ms.
 #pod
 #pod If set to a negative value, connection operations will block indefinitely
 #pod until the server replies or until the operating system TCP/IP stack gives
@@ -217,9 +215,8 @@ sub _build_bson_codec {
 #pod =cut
 
 has connect_timeout_ms => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Num,
-    lazy    => 1,
     builder => '_build_connect_timeout_ms',
 );
 
@@ -248,9 +245,8 @@ sub _build_connect_timeout_ms {
 #pod =cut
 
 has db_name => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     builder => '_build_db_name',
 );
 
@@ -269,9 +265,8 @@ sub _build_db_name {
 #pod =cut
 
 has heartbeat_frequency_ms => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => NonNegNum,
-    lazy    => 1,
     builder => '_build_heartbeat_frequency_ms',
 );
 
@@ -297,9 +292,8 @@ sub _build_heartbeat_frequency_ms {
 #pod =cut
 
 has j => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Bool,
-    lazy    => 1,
     builder => '_build_j',
 );
 
@@ -332,9 +326,8 @@ sub _build_j {
 #pod =cut
 
 has local_threshold_ms => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => NonNegNum,
-    lazy    => 1,
     builder => '_build_local_threshold_ms',
 );
 
@@ -365,9 +358,8 @@ sub _build_local_threshold_ms {
 #pod =cut
 
 has max_time_ms => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => NonNegNum,
-    lazy    => 1,
     builder => '_build_max_time_ms',
 );
 
@@ -398,9 +390,8 @@ sub _build_max_time_ms {
 #pod =cut
 
 has password => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     builder => '_build_password',
 );
 
@@ -445,10 +436,9 @@ has port => (
 #pod =cut
 
 has read_pref_mode => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => ReadPrefMode,
     coerce  => 1,
-    lazy    => 1,
     builder => '_build_read_pref_mode',
 );
 
@@ -483,10 +473,9 @@ sub _build_read_pref_mode {
 #pod =cut
 
 has read_pref_tag_sets => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => ArrayOfHashRef,
     coerce  => 1,
-    lazy    => 1,
     builder => '_build_read_pref_tag_sets',
 );
 
@@ -510,9 +499,8 @@ sub _build_read_pref_tag_sets {
 #pod =cut
 
 has replica_set_name => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     builder => '_build_replica_set_name',
 );
 
@@ -541,9 +529,8 @@ sub _build_replica_set_name {
 #pod =cut
 
 has server_selection_timeout_ms => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Num,
-    lazy    => 1,
     builder => '_build_server_selection_timeout_ms',
 );
 
@@ -556,6 +543,41 @@ sub _build_server_selection_timeout_ms {
     );
 }
 
+#pod =attr server_selection_try_once
+#pod
+#pod This attribute controls whether the client will make only a single attempt
+#pod to find a suitable server for a read or write operation.  The default is true.
+#pod
+#pod When true, the client will B<not> use the C<server_selection_timeout_ms>.
+#pod Instead, if the topology information is stale and needs to be checked or
+#pod if no suitable server is available, the client will make a single
+#pod scan of all known servers to try to find a suitable one.
+#pod
+#pod When false, the client will continually scan known servers until a suitable
+#pod server is found or the C<serverSelectionTimeoutMS> is reached.
+#pod
+#pod See L</SERVER SELECTION> for more details.
+#pod
+#pod This may be set in a connection string with the C<serverSelectionTryOnce>
+#pod option.
+#pod
+#pod =cut
+
+has server_selection_try_once => (
+    is      => 'lazy',
+    isa     => Bool,
+    builder => '_build_server_selection_try_once',
+);
+
+sub _build_server_selection_try_once {
+    my ($self) = @_;
+    return $self->__uri_or_else(
+        u => 'serverselectiontryonce',
+        e => 'server_selection_try_once',
+        d => 1,
+    );
+}
+
 #pod =attr socket_check_interval_ms
 #pod
 #pod If a socket to a server has not been used in this many milliseconds, an
@@ -570,9 +592,8 @@ sub _build_server_selection_timeout_ms {
 #pod =cut
 
 has socket_check_interval_ms => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => NonNegNum,
-    lazy    => 1,
     builder => '_build_socket_check_interval_ms',
 );
 
@@ -604,9 +625,8 @@ sub _build_socket_check_interval_ms {
 #pod =cut
 
 has socket_timeout_ms => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Num,
-    lazy    => 1,
     builder => '_build_socket_timeout_ms',
 );
 
@@ -660,9 +680,8 @@ sub _build_socket_timeout_ms {
 #pod =cut
 
 has ssl => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Bool|HashRef,
-    lazy    => 1,
     builder => '_build_ssl',
 );
 
@@ -695,9 +714,8 @@ sub _build_ssl {
 #pod =cut
 
 has username => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     builder => '_build_username',
 );
 
@@ -747,9 +765,8 @@ sub _build_username {
 #pod =cut
 
 has w => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Int|Str,
-    lazy    => 1,
     builder => '_build_w',
 );
 
@@ -776,9 +793,8 @@ sub _build_w {
 #pod =cut
 
 has wtimeout => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Int,
-    lazy    => 1,
     builder => '_build_wtimeout',
 );
 
@@ -865,14 +881,14 @@ has sasl_mechanism => (
 #pod This option has been renamed as L</connect_timeout_ms>.  If this option is set
 #pod and that one is not, this will be used.
 #pod
-#pod Connection timeout is in milliseconds. Defaults to C<20000>.
+#pod Connection timeout is in milliseconds. Defaults to C<10000>.
 #pod
 #pod =cut
 
 has timeout => (
     is        => 'ro',
     isa       => Int,
-    default   => 20000,
+    default   => 10000,
 );
 
 #--------------------------------------------------------------------------#
@@ -893,11 +909,10 @@ has timeout => (
 #pod =cut
 
 has _read_preference => (
-    is       => 'ro',
+    is       => 'lazy',
     isa      => ReadPreference,
     reader   => 'read_preference',
     init_arg => undef,
-    lazy     => 1,
     builder  => '_build__read_preference',
 );
 
@@ -917,11 +932,10 @@ sub _build__read_preference {
 #pod =cut
 
 has _write_concern => (
-    is     => 'ro',
+    is     => 'lazy',
     isa    => InstanceOf['MongoDB::WriteConcern'],
     reader   => 'write_concern',
     init_arg => undef,
-    lazy     => 1,
     builder  => '_build__write_concern',
 );
 
@@ -964,10 +978,9 @@ has _deferred => (
 #pod =cut
 
 has _topology => (
-    is       => 'ro',
+    is       => 'lazy',
     isa      => InstanceOf ['MongoDB::_Topology'],
     init_arg => undef,
-    lazy     => 1,
     builder  => '_build__topology',
     handles  => { topology_type => 'type' },
     clearer  => '_clear__topology',
@@ -987,6 +1000,7 @@ sub _build__topology {
         type                        => $type,
         replica_set_name            => $self->replica_set_name,
         server_selection_timeout_sec => $self->server_selection_timeout_ms / 1000,
+        server_selection_try_once    => $self->server_selection_try_once,
         local_threshold_sec          => $self->local_threshold_ms / 1000,
         heartbeat_frequency_sec      => $self->heartbeat_frequency_ms / 1000,
         max_wire_version            => MAX_WIRE_VERSION,
@@ -1002,10 +1016,9 @@ sub _build__topology {
 }
 
 has _credential => (
-    is       => 'ro',
+    is       => 'lazy',
     isa      => InstanceOf ['MongoDB::_Credential'],
     init_arg => undef,
-    lazy     => 1,
     builder  => '_build__credential',
 );
 
@@ -1023,10 +1036,9 @@ sub _build__credential {
 }
 
 has _uri => (
-    is       => 'ro',
+    is       => 'lazy',
     isa      => InstanceOf ['MongoDB::_URI'],
     init_arg => undef,
-    lazy     => 1,
     builder  => '_build__uri',
 );
 
@@ -1062,6 +1074,7 @@ my @deferred_options = qw(
   read_pref_tag_sets
   replica_set_name
   server_selection_timeout_ms
+  server_selection_try_once
   socket_check_interval_ms
   socket_timeout_ms
   ssl
@@ -1243,10 +1256,10 @@ sub topology_status {
 #--------------------------------------------------------------------------#
 
 # Undocumented in old MongoDB::MongoClient; semantics don't translate, but
-# best approximation is checking if we can talk to a primary
+# best approximation is checking if we can send a command to a server
 sub connected {
     my ($self) = @_;
-    return try { !! $self->_topology->get_writable_link }
+    return eval { $self->send_admin_command([ismaster => 1]); 1 };
 }
 
 sub send_admin_command {
@@ -1471,7 +1484,6 @@ sub fsync_unlock {
     return $self->get_database('admin')->get_collection('$cmd.sys.unlock')->find_one();
 }
 
-__PACKAGE__->meta->make_immutable( inline_destructor => 0 );
 
 1;
 
@@ -1487,7 +1499,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
@@ -1619,7 +1631,7 @@ If not provided, one will be generated from deprecated configuration options.
 This attribute specifies the amount of time in milliseconds to wait for a
 new connection to a server.
 
-The default is 20,000 ms.
+The default is 10,000 ms.
 
 If set to a negative value, connection operations will block indefinitely
 until the server replies or until the operating system TCP/IP stack gives
@@ -1787,6 +1799,24 @@ See L</SERVER SELECTION> for more details.
 This may be set in a connection string with the C<serverSelectionTimeoutMS>
 option.
 
+=head2 server_selection_try_once
+
+This attribute controls whether the client will make only a single attempt
+to find a suitable server for a read or write operation.  The default is true.
+
+When true, the client will B<not> use the C<server_selection_timeout_ms>.
+Instead, if the topology information is stale and needs to be checked or
+if no suitable server is available, the client will make a single
+scan of all known servers to try to find a suitable one.
+
+When false, the client will continually scan known servers until a suitable
+server is found or the C<serverSelectionTimeoutMS> is reached.
+
+See L</SERVER SELECTION> for more details.
+
+This may be set in a connection string with the C<serverSelectionTryOnce>
+option.
+
 =head2 socket_check_interval_ms
 
 If a socket to a server has not been used in this many milliseconds, an
@@ -1953,7 +1983,7 @@ It has the same valid values as L</auth_mechanism>.  The default is GSSAPI.
 This option has been renamed as L</connect_timeout_ms>.  If this option is set
 and that one is not, this will be used.
 
-Connection timeout is in milliseconds. Defaults to C<20000>.
+Connection timeout is in milliseconds. Defaults to C<10000>.
 
 =head1 METHODS
 
@@ -2209,32 +2239,47 @@ L<http://docs.mongodb.org/manual/reference/connection-string/>.
 
 =head1 SERVER SELECTION
 
-For a single server deployment or a direct connection to a mongod or mongos, all
-reads and writes and sent to that server.  Any read-preference is ignored.
+For a single server deployment or a direct connection to a mongod or
+mongos, all reads and writes and sent to that server.  Any read-preference
+is ignored.
 
-When connected to a deployment with multiple servers, such as a replica set or
-sharded cluster, the driver chooses a server for operations based on the type of
-operation (read or write), the types of servers available and a read preference.
+When connected to a deployment with multiple servers, such as a replica set
+or sharded cluster, the driver chooses a server for operations based on the
+type of operation (read or write), the types of servers available and a
+read preference.
 
-For a replica set deployment, writes are sent to the primary (if available) and
-reads are sent to a server based on the L</read_preference> attribute, which default
-to sending reads to the primary.  See L<MongoDB::ReadPreference> for more.
+For a replica set deployment, writes are sent to the primary (if available)
+and reads are sent to a server based on the L</read_preference> attribute,
+which defaults to sending reads to the primary.  See
+L<MongoDB::ReadPreference> for more.
 
-For a sharded cluster reads and writes are distributed across mongos servers in
-the seed list.  Any read preference is passed through to the mongos and used
-by it when executing reads against shards.
+For a sharded cluster reads and writes are distributed across mongos
+servers in the seed list.  Any read preference is passed through to the
+mongos and used by it when executing reads against shards.
 
 If multiple servers can service an operation (e.g. multiple mongos servers,
 or multiple replica set members), one is chosen at random from within the
-"latency window".  The server with the shortest average round-trip time (RTT)
-is always in the window.  Any servers with an average round-trip time less than
-or equal to the shortest RTT plus the L</local_threshold_ms> are also in the
-latency window.
+"latency window".  The server with the shortest average round-trip time
+(RTT) is always in the window.  Any servers with an average round-trip time
+less than or equal to the shortest RTT plus the L</local_threshold_ms> are
+also in the latency window.
 
-If a server is not immediately available, the driver will block for up to
-L</server_selection_timeout_ms> milliseconds waiting for a suitable server to
-become available.  If no server is available at the end of that time, an
-exception is thrown.
+If a suitable server is not immediately available, what happens next
+depends on the L</server_selection_try_once> option.
+
+If that option is true, a single topology scan will be performed.
+Afterwards if a suitable server is available, it will be returned;
+otherwise, an exception is thrown.
+
+If that option is false, the driver will do topology scans repeatedly
+looking for a suitable server.  When more than
+L</server_selection_timeout_ms> milliseconds have elapsed since the start
+of server selection without a suitable server being found, an exception is
+thrown.
+
+B<Note>: the actual maximum wait time for server selection could be as long
+C<server_selection_timeout_ms> plus the amount of time required to do a
+topology scan.
 
 =head1 SERVER MONITORING AND FAILOVER
 
