@@ -19,13 +19,15 @@ package MongoDB::OID;
 # ABSTRACT: A Mongo Object ID
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use MongoDB::BSON;
 use Moo;
 use MongoDB;
 use MongoDB::_Constants;
-use Types::Standard -types;
+use Types::Standard qw(
+    Str
+);
 use namespace::clean;
 
 #pod =head1 ATTRIBUTES
@@ -145,7 +147,7 @@ MongoDB::OID - A Mongo Object ID
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
