@@ -19,15 +19,21 @@ package MongoDB::Op::_Aggregate;
 # Encapsulate aggregate operation; return MongoDB::QueryResult
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 
 use MongoDB::Error;
 use MongoDB::Op::_Command;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    ArrayOfHashRef
+);
+use Types::Standard qw(
+    HashRef
+    InstanceOf
+    Str
+);
 use boolean;
 use namespace::clean;
 
@@ -128,18 +134,18 @@ sub execute {
     # different server versions
     if ( $options->{explain} ) {
         return MongoDB::QueryResult->_new(
-            _client      => $self->client,
-            address      => $link->address,
-            ns           => '',
-            bson_codec   => $self->bson_codec,
-            batch_size   => 1,
-            cursor_at    => 0,
-            limit        => 0,
-            cursor_id    => MongoDB::QueryResult::_pack_cursor_id(0),
-            cursor_start => 0,
-            cursor_flags => {},
-            cursor_num   => 1,
-            _docs        => [ $res->output ],
+            _client       => $self->client,
+            _address      => $link->address,
+            _ns           => '',
+            _bson_codec   => $self->bson_codec,
+            _batch_size   => 1,
+            _cursor_at    => 0,
+            _limit        => 0,
+            _cursor_id    => MongoDB::QueryResult::_pack_cursor_id(0),
+            _cursor_start => 0,
+            _cursor_flags => {},
+            _cursor_num   => 1,
+            _docs         => [ $res->output ],
         );
     }
 
