@@ -20,7 +20,7 @@ package MongoDB::Op::_BatchInsert;
 # MongoDB::InsertManyResult
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 
@@ -30,9 +30,11 @@ use MongoDB::InsertManyResult;
 use MongoDB::OID;
 use MongoDB::_Constants;
 use MongoDB::_Protocol;
-use MongoDB::_Types -types;
-use Types::Standard -types;
-use Safe::Isa;
+use Types::Standard qw(
+    Str
+    ArrayRef
+    Bool
+);
 use Scalar::Util qw/blessed reftype/;
 use Tie::IxHash;
 use namespace::clean;
