@@ -20,16 +20,22 @@ package MongoDB::Op::_CreateIndexes;
 # or a MongoDB::InsertManyResult, depending on the server version
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 
 use MongoDB::CommandResult;
 use MongoDB::_Constants;
 use MongoDB::_Types -types;
-use Types::Standard -types;
 use MongoDB::Op::_BatchInsert;
-use MongoDB::_Types;
+use Types::Standard qw(
+    ArrayRef
+    HashRef
+    Str
+);
+use MongoDB::_Types qw(
+    WriteConcern
+);
 use Tie::IxHash;
 use namespace::clean;
 
