@@ -20,7 +20,7 @@ package MongoDB::Op::_ListCollections;
 # names
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 
@@ -28,8 +28,14 @@ use MongoDB::Op::_Command;
 use MongoDB::Op::_Query;
 use MongoDB::QueryResult::Filtered;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    Document
+);
+use Types::Standard qw(
+    HashRef
+    InstanceOf
+    Str
+);
 use Tie::IxHash;
 use namespace::clean;
 
