@@ -19,7 +19,7 @@ package MongoDB::Op::_ListIndexes;
 # Encapsulate index list operation; returns array ref of index documents
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 
@@ -27,8 +27,10 @@ use MongoDB::Error;
 use MongoDB::Op::_Command;
 use MongoDB::Op::_Query;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use Types::Standard qw(
+    InstanceOf
+    Str
+);
 use Tie::IxHash;
 use Try::Tiny;
 use Safe::Isa;
