@@ -19,7 +19,7 @@ package MongoDB::Op::_Query;
 # Encapsulate a query operation; returns a MongoDB::QueryResult object
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 
@@ -27,8 +27,17 @@ use MongoDB::BSON;
 use MongoDB::QueryResult;
 use MongoDB::_Constants;
 use MongoDB::_Protocol;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    Document
+);
+use Types::Standard qw(
+    CodeRef
+    HashRef
+    InstanceOf
+    Maybe
+    Num
+    Str
+);
 use namespace::clean;
 
 has db_name => (
@@ -110,18 +119,18 @@ sub execute {
 
     return $class->_new(
         _client      => $self->client,
-        address      => $link->address,
-        ns           => $ns,
-        bson_codec   => $self->bson_codec,
-        batch_size   => $batch_size,
-        cursor_at    => 0,
-        limit        => $self->limit,
-        cursor_id    => $result->{cursor_id},
-        cursor_start => $result->{starting_from},
-        cursor_flags => $result->{flags} || {},
-        cursor_num   => $result->{number_returned},
+        _address      => $link->address,
+        _ns           => $ns,
+        _bson_codec   => $self->bson_codec,
+        _batch_size   => $batch_size,
+        _cursor_at    => 0,
+        _limit        => $self->limit,
+        _cursor_id    => $result->{cursor_id},
+        _cursor_start => $result->{starting_from},
+        _cursor_flags => $result->{flags} || {},
+        _cursor_num   => $result->{number_returned},
         _docs        => $result->{docs},
-        post_filter  => $self->post_filter,
+        _post_filter  => $self->post_filter,
     );
 }
 
