@@ -19,16 +19,18 @@ package MongoDB::QueryResult::Filtered;
 # ABSTRACT: An iterator for Mongo query results with client-side filtering
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
-use Types::Standard -types;
+use Types::Standard qw(
+    CodeRef
+);
 
 extends 'MongoDB::QueryResult';
 
 use namespace::clean;
 
-has post_filter => (
+has _post_filter => (
     is       => 'ro',
     isa      => CodeRef,
     required => 1,
@@ -43,7 +45,7 @@ sub has_next {
     }
     while ( !$self->_drained || $self->_get_more ) {
         my $peek = $self->_docs->[0];
-        if ( $self->post_filter->($peek) ) {
+        if ( $self->_post_filter->($peek) ) {
             # if meets criteria, has_next is true
             return 1;
         }
@@ -71,7 +73,7 @@ MongoDB::QueryResult::Filtered - An iterator for Mongo query results with client
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =for Pod::Coverage has_next
 
