@@ -19,12 +19,14 @@ package MongoDB::ReadPreference;
 # ABSTRACT: Encapsulate and validate read preferences
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
+use Moo;
 use MongoDB::Error;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    ArrayOfHashRef
+    ReadPrefMode
+);
 use namespace::clean -except => 'meta';
 
 use overload (
@@ -114,7 +116,6 @@ sub as_string {
     return $string;
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -130,7 +131,7 @@ MongoDB::ReadPreference - Encapsulate and validate read preferences
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
