@@ -19,12 +19,12 @@ package MongoDB::Role::_CommandCursorOp;
 # MongoDB interface for database commands with cursors
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use MongoDB::Error;
 use MongoDB::QueryResult;
 use Moo::Role;
-use Types::Standard -types;
+
 use namespace::clean;
 
 requires qw/client bson_codec/;
@@ -41,16 +41,16 @@ sub _build_result_from_cursor {
     my $batch = $c->{firstBatch};
     my $qr = MongoDB::QueryResult->_new(
         _client      => $self->client,
-        address      => $res->address,
-        ns           => $c->{ns},
-        bson_codec   => $self->bson_codec,
-        batch_size   => scalar @$batch,
-        cursor_at    => 0,
-        limit        => 0,
-        cursor_id    => MongoDB::QueryResult::_pack_cursor_id( $c->{id} ),
-        cursor_start => 0,
-        cursor_flags => {},
-        cursor_num   => scalar @$batch,
+        _address      => $res->address,
+        _ns           => $c->{ns},
+        _bson_codec   => $self->bson_codec,
+        _batch_size   => scalar @$batch,
+        _cursor_at    => 0,
+        _limit        => 0,
+        _cursor_id    => MongoDB::QueryResult::_pack_cursor_id( $c->{id} ),
+        _cursor_start => 0,
+        _cursor_flags => {},
+        _cursor_num   => scalar @$batch,
         _docs        => $batch,
     );
 }
@@ -60,16 +60,16 @@ sub _empty_query_result {
 
     my $qr = MongoDB::QueryResult->_new(
         _client      => $self->client,
-        address      => $link->address,
-        ns           => '',
-        bson_codec   => $self->bson_codec,
-        batch_size   => 1,
-        cursor_at    => 0,
-        limit        => 0,
-        cursor_id    => MongoDB::QueryResult::_pack_cursor_id(0),
-        cursor_start => 0,
-        cursor_flags => {},
-        cursor_num   => 0,
+        _address      => $link->address,
+        _ns           => '',
+        _bson_codec   => $self->bson_codec,
+        _batch_size   => 1,
+        _cursor_at    => 0,
+        _limit        => 0,
+        _cursor_id    => MongoDB::QueryResult::_pack_cursor_id(0),
+        _cursor_start => 0,
+        _cursor_flags => {},
+        _cursor_num   => 0,
         _docs        => [],
     );
 }
