@@ -19,14 +19,18 @@ package MongoDB::Role::_ReadOp;
 # MongoDB role for read ops that provides read preference
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo::Role;
 
 use MongoDB::ReadPreference;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    ReadPreference
+);
+use Types::Standard qw(
+    Maybe
+);
 use namespace::clean;
 
 with 'MongoDB::Role::_DatabaseOp';
