@@ -19,19 +19,13 @@ package MongoDB::Role::_UpdatePreEncoder;
 # MongoDB interface for pre-encoding and validating update/replace docs
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo::Role;
 use MongoDB::Error;
+use MongoDB::_Constants;
 use namespace::clean;
 
-use constant PERL58 => $] lt '5.010';
-
-use constant {
-    P_INT32 => PERL58 ? "l" : "l<",
-    MIN_KEYED_DOC_LENGTH => 8,
-};
-
 requires qw/bson_codec/;
 
 sub _pre_encode_update {
