@@ -19,7 +19,7 @@ package MongoDB::Role::_WriteOp;
 # MongoDB interface for database write operations
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use MongoDB::BSON;
 use MongoDB::CommandResult;
@@ -27,17 +27,12 @@ use MongoDB::Error;
 use MongoDB::UnacknowledgedResult;
 use MongoDB::_Constants;
 use MongoDB::_Protocol;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    WriteConcern
+);
 use Moo::Role;
-use Syntax::Keyword::Junction qw/any/;
 use namespace::clean;
 
-use constant {
-    NO_JOURNAL_RE => qr/^journaling not enabled/,
-    NO_REPLICATION_RE => qr/^no replication has been enabled/,
-};
-
 with qw/MongoDB::Role::_CommandOp/;
 
 requires qw/db_name _parse_cmd _parse_gle/;
