@@ -18,10 +18,12 @@ package MongoDB::Timestamp;
 # ABSTRACT: Replication timestamp
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
-use Types::Standard -types;
+use Moo;
+use Types::Standard qw(
+    Int
+);
 use namespace::clean -except => 'meta';
 
 #pod =attr sec
@@ -48,7 +50,6 @@ has inc => (
     required => 1,
 );
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -64,7 +65,7 @@ MongoDB::Timestamp - Replication timestamp
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 DESCRIPTION
 
