@@ -19,12 +19,10 @@ package MongoDB::UnacknowledgedResult;
 # ABSTRACT: MongoDB unacknowledged result object
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
 use namespace::clean;
 
 with $_ for qw(
@@ -55,7 +53,7 @@ MongoDB::UnacknowledgedResult - MongoDB unacknowledged result object
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
