@@ -19,12 +19,19 @@ package MongoDB::WriteConcern;
 # ABSTRACT: Encapsulate and validate a write concern
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
+use Moo;
 use MongoDB::Error;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    Booleanpm
+);
+use Types::Standard qw(
+    Bool
+    HashRef
+    Num
+    Str
+);
 use Scalar::Util qw/looks_like_number/;
 use namespace::clean -except => 'meta';
 
@@ -73,17 +80,15 @@ has j => (
 );
 
 has _is_acknowledged => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Bool,
-    lazy    => 1,
     reader  => 'is_acknowledged',
     builder => '_build_is_acknowledged',
 );
 
 has _as_struct => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => HashRef,
-    lazy    => 1,
     reader  => 'as_struct',
     builder => '_build_as_struct',
 );
@@ -116,7 +121,6 @@ sub _w_is_acknowledged {
       && ( looks_like_number( $self->w ) ? $self->w > 0 : length $self->w );
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -132,7 +136,7 @@ MongoDB::WriteConcern - Encapsulate and validate a write concern
 
 =head1 VERSION
 
-version v0.999.999.4
+version v0.999.999.5
 
 =head1 SYNOPSIS
 
