@@ -17,21 +17,28 @@
 package MongoDB::_Credential;
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
+use Moo;
 use MongoDB::Error;
 use MongoDB::Op::_Command;
-use MongoDB::_Types -types;
+use MongoDB::_Types qw(
+    AuthMechanism
+    NonEmptyStr
+);
 
-use Authen::SCRAM::Client 0.003;
 use Digest::MD5 qw/md5_hex/;
 use Encode qw/encode/;
 use MIME::Base64 qw/encode_base64 decode_base64/;
-use Syntax::Keyword::Junction 'any';
 use Tie::IxHash;
 use Try::Tiny;
-use Types::Standard -types;
+use Types::Standard qw(
+    Bool
+    HashRef
+    InstanceOf
+    Str
+);
+
 use namespace::clean -except => 'meta';
 
 has mechanism => (
@@ -47,9 +54,8 @@ has username => (
 );
 
 has source => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => NonEmptyStr,
-    lazy    => 1,
     builder => '_build_source',
 );
 
@@ -71,21 +77,23 @@ has mechanism_properties => (
 );
 
 has _digested_password => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     builder => '_build__digested_password',
 );
 
 has _scram_client => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => InstanceOf['Authen::SCRAM::Client'],
-    lazy    => 1,
     builder => '_build__scram_client',
 );
 
 sub _build__scram_client {
     my ($self) = @_;
+    # loaded only demand as it has a long load time relative to other
+    # modules
+    require Authen::SCRAM::Client;
+    Authen::SCRAM::Client->VERSION(0.003);
     return Authen::SCRAM::Client->new(
         username      => $self->username,
         password      => $self->_digested_password,
@@ -101,7 +109,8 @@ sub _build__digested_password {
 
 sub _build_source {
     my ($self) = @_;
-    return $self->mechanism eq any(qw/DEFAULT MONGODB-CR SCRAM-SHA-1/)
+    my $mech = $self->mechanism;
+    return $mech eq 'DEFAULT' || $mech eq 'MONGODB-CR' || $mech eq 'SCRAM-SHA-1'
       ? 'admin'
       : '$external';
 }
@@ -368,6 +377,5 @@ sub _send_command {
     return $res;
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
