@@ -25,7 +25,7 @@ use warnings;
 package MongoDB::_Link;
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 use Errno qw[EINTR EPIPE];
@@ -35,8 +35,19 @@ use Socket qw/SOL_SOCKET SO_KEEPALIVE SO_RCVBUF IPPROTO_TCP TCP_NODELAY/;
 use Time::HiRes qw/time/;
 use MongoDB::Error;
 use MongoDB::_Constants;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    HostAddress
+    NonNegNum
+    ServerDesc
+);
+use Types::Standard qw(
+    Bool
+    HashRef
+    Maybe
+    Num
+    Str
+    Undef
+);
 use namespace::clean;
 
 my $SOCKET_CLASS =
