@@ -19,11 +19,26 @@ package MongoDB::_Query;
 # Encapsulate query structure and modification
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    BSONCodec
+    Document
+    ReadPreference
+    CursorType
+    IxHash
+);
+
+use Types::Standard qw(
+    Str
+    InstanceOf
+    Maybe
+    HashRef
+    Bool
+    Num
+);
+
 use MongoDB::Op::_Query;
 use Tie::IxHash;
 use namespace::clean;
