@@ -17,13 +17,23 @@
 package MongoDB::_Server;
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use Moo;
+use MongoDB::_Types qw(
+    NonNegNum
+    HostAddress
+    ServerType
+    HostAddressList
+);
+use Types::Standard qw(
+    Bool
+    InstanceOf
+    HashRef
+    Str
+    Num
+);
 use List::Util qw/first/;
-use Syntax::Keyword::Junction qw/any none/;
 use Time::HiRes qw/time/;
 use namespace::clean -except => 'meta';
 
@@ -84,9 +94,8 @@ has is_master => (
 # - PossiblePrimary	Not yet checked, but another member thinks it is the primary.
 
 has type => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => ServerType,
-    lazy    => 1,
     builder => '_build_type',
     writer  => '_set_type',
 );
@@ -122,9 +131,8 @@ sub _build_type {
 
 for my $s (qw/hosts passives arbiters/) {
     has $s => (
-        is      => 'ro',
+        is      => 'lazy',
         isa     => HostAddressList,
-        lazy    => 1,
         builder => "_build_$s",
         coerce  => 1,
     );
@@ -137,9 +145,8 @@ for my $s (qw/hosts passives arbiters/) {
 # address configured as part of replica set: string or null. Default null.
 
 has me => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     builder => "_build_me",
 );
 
@@ -151,9 +158,8 @@ sub _build_me {
 # setName: string or null. Default null.
 
 has set_name => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,
-    lazy    => 1,
     builder => "_build_set_name",
 );
 
@@ -166,9 +172,8 @@ sub _build_set_name {
 # null.
 
 has primary => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Str,           # not HostAddress -- might be empty string
-    lazy    => 1,
     builder => "_build_primary",
 );
 
@@ -180,9 +185,8 @@ sub _build_primary {
 # tags: (a tag set) map from string to string. Default empty.
 
 has tags => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => HashRef,
-    lazy    => 1,
     builder => "_build_tags",
 );
 
@@ -192,21 +196,19 @@ sub _build_tags {
 }
 
 has is_available => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Bool,
-    lazy    => 1,
     builder => "_build_is_available",
 );
 
 sub _build_is_available {
     my ($self) = @_;
-    return $self->type eq none(qw/Unknown PossiblePrimary/);
+    return $self->type ne 'Unknown' && $self->type ne 'PossiblePrimary';
 }
 
 has is_readable => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Bool,
-    lazy    => 1,
     builder => "_build_is_readable",
 );
 
@@ -214,13 +216,13 @@ has is_readable => (
 # ones out. E.g. "Standalone" won't be found in a replica set topology.
 sub _build_is_readable {
     my ($self) = @_;
-    return $self->type eq any(qw/Standalone RSPrimary RSSecondary Mongos/);
+    my $type = $self->type;
+    return !! grep { $type eq $_ } qw/Standalone RSPrimary RSSecondary Mongos/;
 }
 
 has is_writable => (
-    is      => 'ro',
+    is      => 'lazy',
     isa     => Bool,
-    lazy    => 1,
     builder => "_build_is_writable",
 );
 
@@ -228,7 +230,8 @@ has is_writable => (
 # ones out. E.g. "Standalone" won't be found in a replica set topology.
 sub _build_is_writable {
     my ($self) = @_;
-    return $self->type eq any(qw/Standalone RSPrimary Mongos/);
+    my $type = $self->type;
+    return !! grep { $type eq $_ } qw/Standalone RSPrimary Mongos/;
 }
 
 sub updated_since {
@@ -254,9 +257,10 @@ sub matches_tag_set {
 
 sub status_string {
     my ($self) = @_;
-    if ( $self->error ) {
+    if ( my $err = $self->error ) {
+        $err =~ tr[\n][ ];
         return
-          sprintf( "%s (type: %s, error: %s)", map { $self->$_ } qw/address type error/ );
+          sprintf( "%s (type: %s, error: %s)", $self->{address}, $self->{type}, $err);
     }
     else {
         return sprintf( "%s (type: %s)", map { $self->$_ } qw/address type/ );
@@ -266,15 +270,15 @@ sub status_string {
 sub status_struct {
     my ($self) = @_;
     my $info = {
-        address => $self->address,
-        type    => $self->type
+        address          => $self->address,
+        type             => $self->type,
+        last_update_time => $self->last_update_time,
     };
     $info->{error} = $self->error         if $self->error;
     $info->{tags}  = { %{ $self->tags } } if %{ $self->tags };
     return $info;
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
