@@ -17,7 +17,7 @@
 package MongoDB::_Topology;
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Moo;
 use MongoDB::BSON;
@@ -26,23 +26,27 @@ use MongoDB::Op::_Command;
 use MongoDB::ReadPreference;
 use MongoDB::_Constants;
 use MongoDB::_Link;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    BSONCodec
+    NonNegNum
+    TopologyType
+);
+use Types::Standard qw(
+    Bool
+    HashRef
+    InstanceOf
+    Num
+    Str
+);
 use MongoDB::_Server;
 use Config;
 use List::Util qw/first/;
 use Safe::Isa;
-use Syntax::Keyword::Junction qw/any none/;
 use Time::HiRes qw/time usleep/;
 use Try::Tiny;
 
 use namespace::clean;
 
-use constant {
-    EPOCH => 0,
-    MIN_HEARTBEAT_FREQUENCY_USEC => 500_000, # 500ms, not configurable
-};
-
 #--------------------------------------------------------------------------#
 # attributes
 #--------------------------------------------------------------------------#
@@ -116,6 +120,12 @@ has server_selection_timeout_sec => (
     isa => Num,
 );
 
+has server_selection_try_once => (
+    is      => 'ro',
+    default => 1,
+    isa => Bool,
+);
+
 has ewma_alpha => (
     is      => 'ro',
     default => 0.2,
@@ -135,8 +145,7 @@ has bson_codec => (
 );
 
 has number_of_seeds => (
-    is      => 'ro',
-    lazy    => 1,
+    is      => 'lazy',
     builder => '_build_number_of_seeds',
     isa => Num,
 );
@@ -154,6 +163,12 @@ has current_primary => (
     init_arg => undef,
 );
 
+has stale => (
+    is => 'rwp',
+    init_arg => undef,
+    default => 1,
+);
+
 # servers, links and rtt_ewma_sec are all hashes on server address
 
 has servers => (
@@ -317,7 +332,7 @@ sub mark_server_unknown {
 
 sub mark_stale {
     my ($self) = @_;
-    $self->_set_last_scan_time(EPOCH);
+    $self->_set_stale(1);
     return;
 }
 
@@ -326,12 +341,21 @@ sub scan_all_servers {
 
     my ( $next, @ordinary, @to_check );
     my $start_time = time;
+    my $cooldown_time = $start_time - COOLDOWN_SECS;
 
     # anything not updated since scan start is eligible for a check; when all servers
-    # are updated, the loop terminates
+    # are updated, the loop terminates; Unknown servers aren't checked if
+    # they are in the cooldown window since we don't want to wait the connect
+    # timeout each attempt when they are unlikely to have changed status
     while (1) {
-        last
-          unless @to_check = grep { !$_->updated_since($start_time) } $self->all_servers;
+        @to_check =
+          grep {
+            $_->type eq 'Unknown'
+              ? !$_->updated_since($cooldown_time)
+              : !$_->updated_since($start_time)
+          } $self->all_servers;
+
+        last unless @to_check;
 
         if ( $next = first { $_->type eq 'RSPrimary' } @to_check ) {
             $self->check_address( $next->address );
@@ -339,7 +363,7 @@ sub scan_all_servers {
         elsif ( $next = first { $_->type eq 'PossiblePrimary' } @to_check ) {
             $self->check_address( $next->address );
         }
-        elsif ( @ordinary = grep { $_->type eq none(qw/Unknown RSGhost/) } @to_check ) {
+        elsif ( @ordinary = grep { $_->type ne 'Unknown' && $_->type ne 'RSGhost' } @to_check ) {
             $self->_check_oldest_server(@ordinary);
         }
         else {
@@ -348,6 +372,7 @@ sub scan_all_servers {
     }
 
     $self->_set_last_scan_time( time );
+    $self->_set_stale( 0 );
     $self->_check_wire_versions;
     return;
 }
@@ -529,7 +554,7 @@ sub _get_server_link {
         $self->check_address($address);
 
         # topology might have dropped the server
-        $server = $self->servers->{addresses}
+        $server = $self->servers->{$address}
           or return;
 
         my $fresh_link = $self->links->{$address};
@@ -626,7 +651,7 @@ sub _status_string {
         $status .= sprintf( "Topology type: %s; Member status:\n", $self->type );
     }
 
-    $status .= join( "\n", map { "  $_" } map { $_->status_string } $self->all_servers );
+    $status .= join( "\n", map { "  $_" } map { $_->status_string } $self->all_servers ) . "\n";
     return $status;
 }
 
@@ -635,30 +660,51 @@ sub _status_string {
 sub _selection_timeout {
     my ( $self, $method, $read_pref ) = @_;
 
-    my $start_time = time;
+    my $start_time = my $loop_end_time = time();
+    my $max_time = $start_time + $self->server_selection_timeout_sec;
 
-    if ( ($start_time - $self->last_scan_time) > $self->heartbeat_frequency_sec ) {
-        $self->scan_all_servers;
-        $start_time = time; # update after scan
+    if ( $self->last_scan_time + $self->heartbeat_frequency_sec < $start_time ) {
+        $self->_set_stale(1);
     }
 
     while (1) {
-        unless ($self->is_compatible) {
+        if ( $self->stale ) {
+            my $scan_ready_time = $self->last_scan_time + MIN_HEARTBEAT_FREQUENCY_SEC;
+
+            # if not enough time left to wait to check; then caller throws error
+            return if !$self->server_selection_try_once && $scan_ready_time > $max_time;
+
+            # loop_end_time is a proxy for time() to avoid overhead
+            my $sleep_time = $scan_ready_time - $loop_end_time;
+
+            usleep( 1e6 * $sleep_time ) if $sleep_time > 0;
+
+            $self->scan_all_servers;
+        }
+
+        unless ( $self->is_compatible ) {
+            $self->_set_stale(1);
             MongoDB::ProtocolError->throw(
                 "Incompatible wire protocol version. This version of the MongoDB driver is not compatible with the server. You probably need to upgrade this library."
             );
         }
-        if ( my $server = $self->$method($read_pref) ) {
-            return $server;
-        }
-        last if (time - $start_time) > $self->server_selection_timeout_sec;
-    }
-    continue {
-        usleep(MIN_HEARTBEAT_FREQUENCY_USEC); # delay before rescanning
-        $self->scan_all_servers;
-    }
 
-    return; # caller has to throw appropriate timeout error
+        my $server = $self->$method($read_pref);
+
+        return $server if $server;
+
+        $self->_set_stale(1);
+        $loop_end_time = time();
+
+        if ( $self->server_selection_try_once ) {
+            # if already tried once; then caller throws error
+            return if $self->last_scan_time > $start_time;
+        }
+        else {
+            # if selection timed out; then caller throws error
+            return if $loop_end_time > $max_time;
+        }
+    }
 }
 
 my $PRIMARY = MongoDB::ReadPreference->new;
@@ -689,7 +735,8 @@ sub _update_topology_from_link {
         # retry a network error if server was previously known to us
         if (    $_->$_isa("MongoDB::NetworkError")
             and $link->server
-            and $link->server->type eq none(qw/Unknown PossiblePrimary/) )
+            and $link->server->type ne 'Unknown'
+            and $link->server->type ne 'PossiblePrimary' )
         {
             # the earlier reset to unknown avoids us reaching this branch again
             # and recursing forever
@@ -888,10 +935,10 @@ sub _update_ReplicaSetNoPrimary {
         # topology changes might have removed all primaries
         $self->_check_for_primary;
     }
-    elsif ( $server_type eq any(qw/ RSSecondary RSArbiter RSOther /) ) {
+    elsif ( grep { $server_type eq $_ } qw/RSSecondary RSArbiter RSOther/ ) {
         $self->_update_rs_without_primary($new_server);
     }
-    elsif ( $server_type eq any(qw/Standalone Mongos/) ) {
+    elsif ( grep { $server_type eq $_ } qw/Standalone Mongos/ ) {
         $self->_remove_server($new_server);
     }
     else {
@@ -909,10 +956,10 @@ sub _update_ReplicaSetWithPrimary {
     if ( $server_type eq 'RSPrimary' ) {
         $self->_update_rs_with_primary_from_primary($new_server);
     }
-    elsif ( $server_type eq any(qw/ RSSecondary RSArbiter RSOther /) ) {
+    elsif ( grep { $server_type eq $_ } qw/RSSecondary RSArbiter RSOther/ ) {
         $self->_update_rs_with_primary_from_member($new_server);
     }
-    elsif ( $server_type eq any(qw/Unknown Standalone Mongos/) ) {
+    elsif ( grep { $server_type eq $_ } qw/Unknown Standalone Mongos/ ) {
         $self->_remove_server($new_server)
           unless $server_type eq 'Unknown';
     }
@@ -929,7 +976,9 @@ sub _update_ReplicaSetWithPrimary {
 sub _update_Sharded {
     my ( $self, $address, $new_server ) = @_;
 
-    if ( $new_server->type eq any(qw/Unknown Mongos/) ) {
+    my $server_type = $new_server->type;
+
+    if ( grep { $server_type eq $_ } qw/Unknown Mongos/ ) {
         # no-op
     }
     else {
@@ -970,7 +1019,7 @@ sub _update_Unknown {
         # topology changes might have removed all primaries
         $self->_check_for_primary;
     }
-    elsif ( $server_type eq any(qw/ RSSecondary RSArbiter RSOther /) ) {
+    elsif ( grep { $server_type eq $_ }  qw/RSSecondary RSArbiter RSOther/ ) {
         $self->_set_type('ReplicaSetNoPrimary');
         $self->_update_rs_without_primary($new_server);
     }
