@@ -16,10 +16,10 @@
 
 package MongoDB::_Types;
 
-# MongoDB Moose type definitions
+# MongoDB type definitions
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
 use Type::Library
   -base,
@@ -59,7 +59,18 @@ use Type::Library
 );
 
 use Type::Utils -all;
-use Types::Standard -types;
+use Types::Standard qw(
+    Any
+    ArrayRef
+    Dict
+    HashRef
+    Maybe
+    Num
+    Optional
+    Ref
+    Str
+    Undef
+);
 
 use Scalar::Util qw/reftype/;
 use boolean;
