@@ -17,12 +17,19 @@
 package MongoDB::_URI;
 
 use version;
-our $VERSION = 'v0.999.999.4'; # TRIAL from MongoDB-v0.999.999.4-TRIAL.tar.gz
+our $VERSION = 'v0.999.999.5'; # TRIAL from MongoDB-v0.999.999.5-TRIAL.tar.gz
 
-use Moose;
+use Moo;
 use MongoDB::Error;
-use MongoDB::_Types -types;
-use Types::Standard -types;
+use MongoDB::_Types qw(
+    ConnectionStr
+);
+use Types::Standard qw(
+    Any
+    ArrayRef
+    HashRef
+    Str
+);
 use namespace::clean -except => 'meta';
 
 my $uri_re = MongoDB::_Types::connection_uri_re();
@@ -87,6 +94,7 @@ sub _build_valid_options {
             readPreferenceTags
             replicaSet
             serverSelectionTimeoutMS
+            serverSelectionTryOnce
             socketCheckIntervalMS
             socketTimeoutMS
             ssl
@@ -160,7 +168,7 @@ sub BUILD {
                     $parsed{$lc_k} ||= [];
                     push @{$parsed{$lc_k}}, _parse_doc($k,$v);
                 }
-                elsif ( $lc_k eq 'ssl' || $lc_k eq 'journal' ) {
+                elsif ( $lc_k eq 'ssl' || $lc_k eq 'journal' || $lc_k eq 'serverselectiontryonce' ) {
                     $parsed{$lc_k} = __str_to_bool($k, $v);
                 }
                 else {
@@ -200,7 +208,6 @@ use overload
     '""' => sub { $_[0]->uri },
     'fallback' => 1;
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
